/*
 * Display control for Huge RGB Display
 */
 
#ifndef ___DISPCTL_H___
#define ___DISPCTL_H___

#include <stdint.h>

// LED bit clock: as high as the display will support with the cabling used
#define LED_CLOCK											12000000 // 12500000

// Display core parameters
#define DISP_SUBPIX_WIDTH							160 // 160
#define DISP_SUBPIX_HEIGHT						120 // 120

#define DISP_PIX_WIDTH								80 // 80
#define DISP_PIX_HEIGHT								60 // 60

#define DISP_SUBFIELD_SIZE_BYTES			((DISP_PIX_WIDTH * DISP_PIX_HEIGHT) / 2)
#define DISP_PIXELS										(DISP_PIX_WIDTH * DISP_PIX_HEIGHT)

#define PIX_AT(x, y)									((x) + ((y) * DISP_PIX_WIDTH))

#define SF_STRIDE											(DISP_PIX_WIDTH / 2)

// Drive configuration:
//   One SSI port driving WHOLE panel (SSI0) with many buffer ICs to reduce loading issues
//   20 MHz clock 
// 
// Each group of eight modules has a separate latch signal (20 latch signals)
// All latches fall low to latch data.  A latch staying high means the module will ignore
// the data (it will not be committed to the output of the module.)
//
// Data is committed to each group of 8 displays in turn, then latched on each latch signal
#define DISP_NUM_LATCHES							20

// Display is treated as 20 blocks of 7/8 modules each with 128 subpixels
// Note that some inner-modules are omitted to keep the 80x60 effective resolution. 
#define DISP_NUM_SUPERBLOCKS				 	20
#define DISP_NUM_INNER_MODULES				8
#define DISP_NUM_MODULES							150

// Number of subfields (fixed) and refresh rate
// Refresh rate should be set to the highest that the software can manage with the number of subfields
#define DISP_SUBFIELDS								10
#define DISP_REFRESH_RATE_DEFAULT			60

// Delays between changes
#define DISPCTL_CHG_DLY1()						__asm("nop"); __asm("nop"); __asm("nop"); __asm("nop"); \
																			__asm("nop"); __asm("nop"); __asm("nop"); 

// Drives latch signal low then high causing a latch
// Latch pulse minimum 50ns set up after last clock, 100ns pulse width.
/*
#define DISPCTL_LATCH(lut)						DISPCTL_CHG_DLY3(); DISPCTL_CHG_DLY3(); \
																			HWREG(lut.port_base + (GPIO_O_DATA + (lut.port_mask << 2))) = lut.port_invmask; \
																			DISPCTL_CHG_DLY3(); DISPCTL_CHG_DLY3(); DISPCTL_CHG_DLY3(); DISPCTL_CHG_DLY3(); \
																			HWREG(lut.port_base + (GPIO_O_DATA + (lut.port_mask << 2))) = lut.port_mask; \
																			DISPCTL_CHG_DLY3(); DISPCTL_CHG_DLY3(); 
*/

#define DISPCTL_LATCH_LOW(lut)				HWREG(lut.port_base + (GPIO_O_DATA + (lut.port_mask << 2))) = lut.port_invmask; 
#define DISPCTL_LATCH_HIGH(lut)				HWREG(lut.port_base + (GPIO_O_DATA + (lut.port_mask << 2))) = lut.port_mask;

// Global odd/even for all display modules
#define DISPCTL_ODDEVEN_PORT					GPIO_PORTL_BASE
#define DISPCTL_ODDEVEN_BIT						GPIO_PIN_2

#define DISPCTL_ODDEVEN_HIGH()				HWREG(DISPCTL_ODDEVEN_PORT + (GPIO_O_DATA + (DISPCTL_ODDEVEN_BIT << 2))) = DISPCTL_ODDEVEN_BIT;
#define DISPCTL_ODDEVEN_LOW()					HWREG(DISPCTL_ODDEVEN_PORT + (GPIO_O_DATA + (DISPCTL_ODDEVEN_BIT << 2))) = ~DISPCTL_ODDEVEN_BIT;

// Display address (in-superblock) mux pins	
#define DISPCTL_ADDR_BIT0_PORT				GPIO_PORTL_BASE
#define DISPCTL_ADDR_BIT0_MASK				GPIO_PIN_1
#define DISPCTL_ADDR_BIT1_PORT				GPIO_PORTL_BASE
#define DISPCTL_ADDR_BIT1_MASK				GPIO_PIN_0
#define DISPCTL_ADDR_BIT2_PORT				GPIO_PORTD_BASE
#define DISPCTL_ADDR_BIT2_MASK				GPIO_PIN_0

// Display latch super select (LATCH_SEL_n)
// Only LATCH_SEL_0 implemented as multi-display not currently supported
#define DISPCTL_LATCH_SEL_0_PORT			GPIO_PORTF_BASE
#define DISPCTL_LATCH_SEL_0_PIN				GPIO_PIN_3

// Display superblock address write
#define DISPCTL_SB_ADDR_WRITE(lut)		HWREG((lut).port_0 + (GPIO_O_DATA + ((lut).port_mask_0 << 2))) = ~(lut).bit_mask_0; \
																			HWREG((lut).port_1 + (GPIO_O_DATA + ((lut).port_mask_1 << 2))) = ~(lut).bit_mask_1; \
																			HWREG((lut).port_2 + (GPIO_O_DATA + ((lut).port_mask_2 << 2))) = ~(lut).bit_mask_2; \

// Display output enable ports
// These need to be connectable to timer peripherals, which generate the respective red/green/blue low pulses
#define DISPCTL_R_OE_PORT							GPIO_PORTC_BASE
#define DISPCTL_R_OE_BIT							GPIO_PIN_7
#define DISPCTL_G_OE_PORT							GPIO_PORTB_BASE
#define DISPCTL_G_OE_BIT							GPIO_PIN_2
#define DISPCTL_B_OE_PORT							GPIO_PORTB_BASE
#define DISPCTL_B_OE_BIT							GPIO_PIN_3

#define DISPCTL_R_OE_OFF()						HWREG(DISPCTL_R_OE_PORT + (GPIO_O_DATA + (DISPCTL_R_OE_BIT << 2))) =  DISPCTL_R_OE_BIT;
#define DISPCTL_G_OE_OFF()						HWREG(DISPCTL_G_OE_PORT + (GPIO_O_DATA + (DISPCTL_G_OE_BIT << 2))) =  DISPCTL_G_OE_BIT;
#define DISPCTL_B_OE_OFF()						HWREG(DISPCTL_B_OE_PORT + (GPIO_O_DATA + (DISPCTL_B_OE_BIT << 2))) =  DISPCTL_B_OE_BIT;
#define DISPCTL_R_OE_ON()							HWREG(DISPCTL_R_OE_PORT + (GPIO_O_DATA + (DISPCTL_R_OE_BIT << 2))) = ~DISPCTL_R_OE_BIT;
#define DISPCTL_G_OE_ON()							HWREG(DISPCTL_G_OE_PORT + (GPIO_O_DATA + (DISPCTL_G_OE_BIT << 2))) = ~DISPCTL_G_OE_BIT;
#define DISPCTL_B_OE_ON()							HWREG(DISPCTL_B_OE_PORT + (GPIO_O_DATA + (DISPCTL_B_OE_BIT << 2))) = ~DISPCTL_B_OE_BIT;

// Display output enable timing
#define DISPCTL_OE_PRESCALER					12			// 100ns min pulse, 6.55ms max pulse

// Maximum possible OE pulse width (in counts) at 60Hz timing
// This forms the base of other pulse width calculations
#define DISPCTL_OE_MAX_PULSE					12000 //41600

// OE scaling to allow for a shifted R-G-B drive.  This reduces OE pulse widths 
// so red fires first, followed by green, followed by blue. 
// The effect is to reduce ripple on the power supply and allow the blue subfield to 
// trigger the next load of data into the panel.
// There is a calculated offset for each channel based on the channel pulse width.
#define DISPCTL_OE_SFTDRV_R_OFFS			100 
#define DISPCTL_OE_SFTDRV_G_OFFS			200
#define DISPCTL_OE_SFTDRV_B_OFFS			300 
#define DISPCTL_OE_SFTDRV_SCALE				700 

// Offset from OE all timing, which is the delay beyond the maximum OE width that will be
// used before the next subfield
#define DISPCTL_OE_OFFSET_ALL					150			// relative to width of field * 1024

// Display intensity scaling
#define DISP_INT_SCALE								1024		// = max intensity
#define DISP_INT_SHIFT								10			// 2^N = DISP_INT_SCALE

// Display frame generator prescaler
// The frame generator operates from around 50 - 200Hz, depending on configuration
// It is set up to allow a minimum of 25Hz (40ms max time)... cinematic! 
#define DISPCTL_FRGEN_PRESCALE				74
#define DISPCTL_FRGEN_CALC_FREQ(hz)		(1.0f / (hz * (1.0f / (CPU_CLOCK / DISPCTL_FRGEN_PRESCALE))))

// OE states
#define OE_STATE_GOLOW								1				// Go low in ISR
#define OE_STATE_GOHIGH								2				// Go high in ISR

// ABL scale factor: conversion of luminance (0-4095) to milliwatts (0-36000)
#define ABL_POW_MULT									9002
#define ABL_POW_SHIFT									10

// ABL averaging coefficients (IIR)
#define ABL_AVG_PWR_MULT_NEW					1				// New value
#define ABL_AVG_PWR_MULT_CUR					1023		// Current value
#define ABL_AVG_PWR_SHIFT							10			// Shift for divider

// LED divider for frame sync indication
#define LED_DIVIDE_FSYNC							16

// Clamps written value to zero if it goes below zero
#define CLAMP0(loc, x)								(((int32_t)(loc) - (x)) <= 0 ? (0) : ((loc) - (x)))

extern uint32_t abl_peak_power;
extern uint32_t abl_avg_power;
extern uint32_t calc_cur_power;
extern uint32_t calc_avg_power;
extern uint32_t abl_limit_oe;
	
extern uint32_t disp_frame;
extern uint32_t oe_ints_global;

extern struct pix_rgbg_t *disp_current_ptr;
extern struct pix_rgbg_t *disp_working_ptr;

extern uint16_t *gamma_table_red;
extern uint16_t *gamma_table_green;
extern uint16_t *gamma_table_blue;

struct pix_rgbg_t {
	// Gamma corrected values
	int16_t r, g1, b, g2;
};

struct disp_latch_lut_t {
	uint32_t port_base;
	uint32_t port_mask;
	uint32_t port_invmask;
};

struct disp_addr_lut_t {
	uint32_t port_0;
	uint32_t bit_mask_0;
	uint32_t port_1;
	uint32_t bit_mask_1;
	uint32_t port_2;
	uint32_t bit_mask_2;
	uint32_t port_mask_0;
	uint32_t port_mask_1;
	uint32_t port_mask_2;
};

struct disp_xyoff_t {
	uint32_t x, y, num_modules, latch;
};

void Timer0AIntHandler();
void Timer0BIntHandler();
void Timer1AIntHandler();
void Timer1BIntHandler();
void Timer2AIntHandler();

void disp_io_setup();
void disp_output_subfield(struct pix_rgbg_t *fb, uint32_t bitmask);
void disp_run();
void disp_debug();

// Frame control
void disp_dither_calculate();
void disp_drive_frame();
void disp_drive_subfield();
void disp_wait_for_frame();
void disp_flush_display(uint32_t block);

// Brightness control
void disp_set_brightness(uint32_t bri);
void disp_set_brightness_direct(uint32_t bri);

// Pixel control
void disp_write_pixel(uint32_t x, uint32_t y, struct pix_rgbg_t *pix);
void disp_write_pixel_rgb(uint32_t x, uint32_t y, uint32_t r, uint32_t g, uint32_t b);

// Gamma table control
void disp_switch_gamma(uint32_t mode);
void disp_write_gamma(uint32_t index, uint32_t col, uint32_t value);
void disp_set_oe(uint32_t r, uint32_t g, uint32_t b);

#endif // ___DISPCTL_H___
